@@ -18,7 +18,7 @@ class JenkinsEnableJobTest(JenkinsJobsTestBase):
 
         self.assertEqual(
             jenkins_mock.call_args_list[0][0][0].get_full_url(),
-            'http://example.com/job/TestJob/enable')
+            self.make_url('job/TestJob/enable'))
         self.assertTrue(self.j.job_exists('TestJob'))
         self._check_requests(jenkins_mock.call_args_list)
 
@@ -33,6 +33,6 @@ class JenkinsEnableJobTest(JenkinsJobsTestBase):
 
         self.assertEqual(
             jenkins_mock.call_args_list[0][0][0].get_full_url(),
-            'http://example.com/job/a%20Folder/job/TestJob/enable')
+            self.make_url('job/a%20Folder/job/TestJob/enable'))
         self.assertTrue(self.j.job_exists('a Folder/TestJob'))
         self._check_requests(jenkins_mock.call_args_list)
